@@ -32,7 +32,9 @@ special_sig_fns : dict
 
 """
 
-__version__ = "2.1.4"
+__version__ = "2.1.5"
 __all__ = ['init_env', 'decider_str_lookup', 'special_sig_fns', 'stata_run_params_factory']
-from .sconstruct_aux import decider_str_lookup, dependency_newer_then_content_changed, \
-    changed_timestamp_then_dependency_newer_then_content_content, special_sig_fns, init_env, stata_run_params_factory
+from .deciders import decider_str_lookup, dependency_newer_then_content_changed, \
+    changed_timestamp_then_dependency_newer_then_content_content
+from .special_sigs import special_sig_fns
+from .stata_utils import init_env, stata_run_params_factory
